#
# ifcore.rb
#
#   Copyright (c) 1999 Minero Aoki <aamine@dp.u-netsurf.ne.jp>
#
#   This program is free software.
#   you can distribute/modify this program under the terms of
#   the GNU Lesser General Public License version 2 or later.
#

require 'est/all'
require 'gtk'


module EST

  Interface = 'mailest'
  Interface.freeze


  class Core

    def initialize
      super
      @setter = SetterManager.new

      @working       = false
      @shutting_down = false

      @editers = []
    end

    attr :setter


    public

    attr :working

    def trigger
      return false if @working
      @working = true

      first_profile = construct
      @mailbox.init0

      CORE.profile.select first_profile
      @mailbox.init1

      notice "mailest ready"
      Gtk.main
    end


    def notice( str )
      @mailbox.write str
    end

    
    def address_book
      unless @addrbook then
        @addrbook = AddressBook.new( @rc['core']['addrfile'] )
      end
      @addrbook
    end


    def edit( port )
      unless @shutting_down then
        rc = CORE.ifrc['editer']
        cls = (rc['type'] == 'internal') ? InternalEditer : ExternalEditer
        @editers.push cls.new( port, rc )
        return true
      else
        return false
      end
    end

    def edit_done( ed )
      unless @shutting_down then
        @editers.delete( ed )
      end
    end

    def editers
      @editers.dup
    end


    def send_from_draft( arr = nil )
      unless arr then
        arr = []
        mailbox.draft.each_selection {|i| arr.push i }
      end
      super arr
    end


    def shutdown( force = false )
      return if @shutting_down
      begin
        @shutting_down = true

        unless force then
          unless quit_ok? then
            return
          end

          notice 'going to shutdown...'
          @editers.each {|ed| ed.shutdown }
          @editers.clear
          super()
        end

        exit 0
      ensure
        @shutting_down = false
      end
    end


    attr :ifrc, true   # tmp
    private

    def quit_ok?
      true         # tmp
    end


  end   # class Core


end   # module EST
